pub struct RootFilesystemConfig {
pub mode: RootFilesystemMode,
pub disable_default_base_layer: bool,
pub lowers: Vec<RootFilesystemLowerDescriptor>,
pub bootstrap_entries: Vec<RootFilesystemEntry>,
}Fields
mode: RootFilesystemModedisable_default_base_layer: boollowers: Vec<RootFilesystemLowerDescriptor>bootstrap_entries: Vec<RootFilesystemEntry>Trait Implementations
Sourceimpl Clone for RootFilesystemConfig
impl Clone for RootFilesystemConfig
Sourcefn clone(&self) -> RootFilesystemConfig
fn clone(&self) -> RootFilesystemConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RootFilesystemConfig
impl Debug for RootFilesystemConfig
Sourceimpl Default for RootFilesystemConfig
impl Default for RootFilesystemConfig
Sourceimpl<'de> Deserialize<'de> for RootFilesystemConfig
impl<'de> Deserialize<'de> for RootFilesystemConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RootFilesystemConfig
Sourceimpl PartialEq for RootFilesystemConfig
impl PartialEq for RootFilesystemConfig
Sourcefn eq(&self, other: &RootFilesystemConfig) -> bool
fn eq(&self, other: &RootFilesystemConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RootFilesystemConfig
impl Serialize for RootFilesystemConfig
impl StructuralPartialEq for RootFilesystemConfig
Sourceimpl TS for RootFilesystemConfig
impl TS for RootFilesystemConfig
Sourcetype WithoutGenerics = RootFilesystemConfig
type WithoutGenerics = RootFilesystemConfig
If this type does not have generic parameters, then
WithoutGenerics should just be Self.
If the type does have generic parameters, then all generic parameters must be replaced with
a dummy type, e.g ts_rs::Dummy or ().
The only requirement for these dummy types is that EXPORT_TO must be None. Read moreSourcefn decl_concrete() -> String
fn decl_concrete() -> String
Declaration of this type using the supplied generic arguments.
The resulting TypeScript definition will not be generic. For that, see
TS::decl().
If this type is not generic, then this function is equivalent to TS::decl().Sourcefn decl() -> String
fn decl() -> String
Declaration of this type, e.g.
type User = { user_id: number, ... }.
This function will panic if the type has no declaration. Read moreSourcefn inline() -> String
fn inline() -> String
Formats this types definition in TypeScript, e.g
{ user_id: number }.
This function will panic if the type cannot be inlined.Sourcefn inline_flattened() -> String
fn inline_flattened() -> String
Flatten a type declaration.
This function will panic if the type cannot be flattened.
This function will panic if the type cannot be flattened.
Sourcefn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all type parameters of this type.
Sourcefn output_path() -> Option<&'static Path>
fn output_path() -> Option<&'static Path>
Returns the output path to where
The returned path does not include the base directory from
T should be exported.The returned path does not include the base directory from
TS_RS_EXPORT_DIR. Read moreSourcefn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all dependency of this type.
Sourceconst DOCS: Option<&'static str> = None
const DOCS: Option<&'static str> = None
JSDoc comment to describe this type in TypeScript - when
TS is derived, docs are
automatically read from your doc comments or #[doc = ".."] attributesSourcefn dependencies() -> Vec<Dependency>where
Self: 'static,
fn dependencies() -> Vec<Dependency>where
Self: 'static,
Resolves all dependencies of this type recursively.
Sourcefn export() -> Result<(), ExportError>where
Self: 'static,
fn export() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem.
To export this type together with all of its dependencies, use
TS::export_all. Read moreSourcefn export_all() -> Result<(), ExportError>where
Self: 'static,
fn export_all() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem, together with all of its dependencies.
To export only this type, without its dependencies, use
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
fn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
Manually export this type into the given directory, together with all of its dependencies.
To export only this type, without its dependencies, use
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_to_string() -> Result<String, ExportError>where
Self: 'static,
fn export_to_string() -> Result<String, ExportError>where
Self: 'static,